@@ -9,7 +9,6 @@ __all__ = [
     "E",
     "flatten",
     "Image",
-    "inspect",
     "jitter",
     "L",
     "lzip",
@@ -65,7 +64,7 @@ __all__ = [
     "display",
     "typedispatch",
     "deepcopy",
-    "batchify"
+    "batchify",
 ]
 
 from .logger import *
@@ -184,71 +183,6 @@ rand = lambda n=6: "".join(
 )
 
 
-def inspect(*arrays, **kwargs):
-    """
-    shows shape, min, max and mean of an array/list/dict of oreys
-    Usage:
-    >>> inspect(arr1, arr2, arr3, [arr4,arr5,arr6], arr7, [arr8, arr9],...)
-    where every `arr` is  assume to have a .shape, .min, .max and .mean methods
-    """
-    depth = kwargs.get("depth", 0)
-    names = kwargs.get("names", None)
-    if names is not None:
-        if "," in names:
-            names = names.split(",")
-        assert len(names) == len(
-            arrays
-        ), "Give as many names as there are tensors to inspect"
-    line()
-
-    for ix, arr in enumerate(arrays):
-        name = "\t" * depth
-        name = (
-            name + f"{names[ix].upper().strip()}:\n" + name
-            if names is not None
-            else name
-        )
-        name = name
-        typ = type(arr).__name__
-
-        if isinstance(arr, (list, tuple)):
-            if arr == []:
-                print("[]")
-            else:
-                print(f"{name}List Of {len(arr)} items")
-                inspect(*arr[:10], depth=depth + 1)
-                if len(arr) > 10:
-                    print("\t" * (depth + 1) + f"... ... {len(arr) - 10} more item(s)")
-
-        elif isinstance(arr, dict):
-            print(f"{name}Dict Of {len(arr)} items")
-            for ix, (k, v) in enumerate(arr.items()):
-                # print(f'\t'*(depth)+f' {k}'.upper())
-                inspect(v, depth=depth + 1, names=[k])
-                if ix == 4:
-                    break
-            if len(arr) > 5:
-                print("\t" * (depth) + f"... ... {len(arr) - 10} more item(s)")
-
-        elif hasattr(arr, "shape"):
-            sh, m, M, dtype = arr.shape, arr.min(), arr.max(), arr.dtype
-            try:
-                me = arr.mean()
-            except:
-                me = arr.float().mean()
-            print(
-                f"{name}{typ}\tShape: {sh}\tMin: {m:.3f}\tMax: {M:.3f}\tMean: {me:.3f}\tdtype: {dtype}"
-            )
-            line()
-        else:
-            try:
-                ln = len(arr)
-                print(f"{name}{typ} Length: {ln}")
-                line()
-            except:
-                print(f"{name}{typ}: {arr}")
-
-
 randint = lambda high: np.random.randint(high)
 
 
@@ -651,7 +585,10 @@ def subplots(ims, nc=5, figsize=(5, 5), silent=True, **kwargs):
 
 def df2bbs(df):
     if "bb" in df.columns:
-        return bbfy(df["bb"].values.tolist())
+        try:
+            return bbfy(df["bb"].values.tolist())
+        except:
+            return bbfy(df["bb"].map(lambda x: eval(x)).values.tolist())
     return [BB(bb) for bb in df[list("xyXY")].values.tolist()]
 
 
@@ -724,7 +661,9 @@ def resize_old(im: np.ndarray, sz: Union[float, Tuple[int, int]]):
     return cv2.resize(im, (W, H))
 
 
-def resize(im: np.ndarray, sz: Union[float, Tuple[int, int], Tuple[str, Tuple[int, int]]]):
+def resize(
+    im: np.ndarray, sz: Union[float, Tuple[int, int], Tuple[str, Tuple[int, int]]]
+):
     """Resize an image based on info from sz
     *Aspect ratio is preserved
     Examples:
@@ -913,6 +852,7 @@ def shrink_bbs(bbs, eps=0.2):
         for (x, y, X, Y), (h, w) in zip(bbs, shs)
     ]
 
+
 def batchify(n, bs):
     n = deepcopy(n)
     l = []
@@ -924,9 +864,7 @@ def batchify(n, bs):
         if isinstance(n, int):
             l.append(bs)
         else:
-            l.append(
-                n[:bs]
-            )
+            l.append(n[:bs])
             del n[:bs]
         remaining -= bs
     if isinstance(n, int):
@@ -934,4 +872,3 @@ def batchify(n, bs):
     else:
         l.append(n[:remaining])
     return l
-    
\ No newline at end of file
